const pluginMaterial = require('@winfe/plugin-material-config');
const path = require('path');
const loadConfig = require('../../lib/node/loadConfig');

const PROXY_APP_IP = 'http://172.16.7.60';
const MATERIAL_NAME = process.env.MATERIAL_NAME;
const MATERIAL_CATEGORY = process.env.MATERIAL_CATEGORY;

const isDev = process.env.NODE_ENV === 'development';
const cwd = process.env.VUEPRESS_CWD || process.cwd();
const baseUrl = isDev
  ? '/'
  : process.env.VUEPRESS_BASE_URL || `/material-docs/${MATERIAL_CATEGORY}/${MATERIAL_NAME}/`;

const baseVuePressConfig = {
  base: baseUrl, //部署站点基础路径
  title: process.env.MATERIAL_TITLE, // 网站标题
  description: '介绍关于前端物料的安装使用方法',
  head: [['link', { rel: 'stylesheet', href: 'http://172.16.7.58/web-public/base-ui/index.css' }]],
  plugins: [
    'demo-container',
    pluginMaterial.default,
    [
      {
        name: '@winfe/compat-userconfig-plugin',
        enhanceAppFiles: path.resolve(
          path.resolve(path.resolve(cwd, './docs'), '.vuepress'),
          'enhanceApp.js'
        )
      }
    ]
  ],
  themeConfig: {
    search: false,
    nav: [
      {
        text: '物料平台',
        link: 'http://172.16.6.214/material-web/'
      }
    ],
    sidebar: []
  },
  configureWebpack: {
    module: {
      rules: [
        {
          test: /\.scss$/,
          use: [
            {
              loader: 'style-resources-loader',
              options: {
                patterns: [require.resolve('@winfe/theme-helper')]
              }
            }
          ]
        }
      ]
    }
  }
};

module.exports = async (ctx) => {
  let userVuePressConfig = loadConfig(path.resolve(path.resolve(cwd, './docs'), '.vuepress'));
  if (typeof userVuePressConfig === 'function') {
    userVuePressConfig = await userVuePressConfig(ctx);
  }
  return Object.assign(baseVuePressConfig, userVuePressConfig);
};
